@@ -44,8 +44,8 @@ opts, args = o.parse_args(sys.argv[1:])
 uv = a.miriad.UV(args[0])
 if not opts.src is None:
     aa = a.cal.get_aa(opts.cal, uv['sdf'], uv['sfreq'], uv['nchan'])
-    srclist,cutoff = a.scripting.parse_srcs(opts.src)
-    cat = a.cal.get_catalog(opts.cal, srclist, cutoff)
+    srclist,cutoff,catalogs = a.scripting.parse_srcs(opts.src, opts.cat)
+    cat = a.cal.get_catalog(opts.cal, srclist, cutoff, catalogs)
     src = cat[opts.src]
 else:
     aa = a.cal.get_aa(opts.cal, uv['sdf'], uv['sfreq'], uv['nchan'])
