@@ -25,8 +25,8 @@ o.add_option('--cnt', dest='cnt', type='int', default=0,
     help='Start counting output images from this number.  Default 0.')
 o.add_option('--fmt', dest='fmt', default='im%04d',
     help='A format string for counting successive images written to files.  Default is im%04d (i.e. im0001).')
-o.add_option('-u', '--uniform', dest='uniform', type='float', default=0,
-    help="Use uniform (rather than natural) weighting for uv bins that have a weight above the specified fraction of the maximum weighting.")
+o.add_option('--skip_phs', dest='skip_phs', action='store_true',
+    help='Do not phase visibilities before gridding.')
 o.add_option('--skip_amp', dest='skip_amp', action='store_true',
     help='Do not use amplitude information to normalize visibilities.')
 o.add_option('--skip_bm', dest='skip_bm', action='store_true',
@@ -41,6 +41,8 @@ o.add_option('--no_w', dest='no_w', action='store_true',
     help="Don't use W projection.")
 o.add_option('--altmin', dest='altmin', type='float', default=0,
     help="Minimum allowed altitude for pointing, in degrees.  When phase center is lower than this altitude, data is omitted.  Default is 0.")
+o.add_option('--minuv', dest='minuv', type='float', default=0,
+    help="Minimum distance from the origin in the UV plane (in wavelengths) for a baseline to be included.  Default is 0.")
 o.add_option('--buf_thresh', dest='buf_thresh', default=2e6, type='float',
     help='Maximum amount of data to buffer before gridding.  Excessive gridding takes performance hit, but if buffer exceeds memory available... ouch.')
 opts, args = o.parse_args(sys.argv[1:])
@@ -66,8 +68,8 @@ if opts.src == 'zen':
     srcs = [a.phs.RadioFixedBody(aa.sidereal_time(), aa.lat, name='zen')]
     cat = a.phs.SrcCatalog(srcs)
 elif not opts.src is None: 
-    srclist,cutoff = a.scripting.parse_srcs(opts.src)
-    cat = a.cal.get_catalog(opts.cal, srclist, cutoff)
+    srclist,cutoff,catalogs = a.scripting.parse_srcs(opts.src, opts.cat)
+    cat = a.cal.get_catalog(opts.cal, srclist, cutoff, catalogs)
 else:
     ras,decs = a.map.facet_centers(opts.facets, ncrd=2)
     srcs = [a.phs.RadioFixedBody(ra,dec,name=str(i)) 
@@ -141,7 +143,6 @@ def img_it(im):
     global n_ints
     #print 'Imaging with %d integrations' % n_ints
     n_ints = 0
-    if opts.uniform > 0: im.uniform_wgt(thresh=opts.uniform)
     # Form dirty images/beams
     uvs = a.img.recenter(n.abs(im.uv).astype(n.float), (DIM/2,DIM/2))
     bms = a.img.recenter(n.abs(im.bm[0]).astype(n.float), (DIM/2,DIM/2))
@@ -198,8 +199,9 @@ for srccnt, s in enumerate(cat.values()):
           d,f = d.take(chans), f.take(chans)
           if not opts.skip_amp: d /= aa.passband(i,j)
           # Throws PointingError if not up:
-          d = aa.phs2src(d, s, i, j)
+          if not opts.skip_phs: d = aa.phs2src(d, s, i, j)
           u,v,w = aa.gen_uvw(i,j,src=s)
+          longenough = n.where(n.sqrt(u**2+v**2) < opts.minuv, 0, 1).squeeze()
           if not opts.skip_bm:
               # Calculate beam strength for weighting purposes
               wgt = aa.bm_response(i,j,pol=opts.pol).squeeze()
@@ -207,7 +209,7 @@ for srccnt, s in enumerate(cat.values()):
               # by another factor of the beam response.
               d *= wgt; wgt *= wgt
           else: wgt = n.ones(d.shape, dtype=n.float)
-          valid = n.logical_not(f)
+          valid = n.logical_and(n.logical_not(f), longenough)
           d = d.compress(valid)
           if len(d) == 0: continue
           n_ints += 1
